#' @title 2004 US Presidential elections
#' @name us_election_2004
#' @description This data set contains annotation of corpus data on the particle placement/movement alternation, i.e. the alternation between 'John pick up the book' and 'John picked the book up'.
#' @docType data
#'
#' @format A data frame with 200 observations/cases and 8 variables:
#' \describe{
#'   \item{CASE}{Numeric: case number for each state, in the interval [1, 50]}
#'   \item{STATE}{Factor: the state each row represents, with 50 levels}
#'   \item{CAN_ELECT}{Factor: which candidate won the election in this state, with levels "Bush", "Kerry"}
#'   \item{AVE_IQ}{Numeric: the average IQ value per state, in the interval [85, 113]}
#'   \item{AVE_INCOME}{Numeric: the average income per state, in the interval [14088, 26979]}
#'   \item{DO_ANIM}{Numeric: the population density per state, in the interval [1.137, 1174.564]}
#' }
#'
#' @details Disclaimer: I have no factual information about the source, reliability, or trustworthiness of the income and IQ values in this data set; I am using it because it's a data set with statistically instructive properties and because of the entertainment value (and current recognizability) of non-US politicians' comments in the lower half of [this page](http://marc.merlins.org/mirrors/US-Election-IQ2004.htm), where I saw this data set mentioned for the first time; also, I take no stand on how these data should be interpreted. As for the population densities, those were computed from [these land area values](https://en.wikipedia.org/wiki/List_of_U.S._states_and_territories_by_area) and the (2003) population values quoted on p. 20 of [this](https://www.census.gov/prod/2004pubs/04statab/pop.pdf).
#' @source \url https://web.archive.org/web/20041106061214/http://www.commonalty.com/iq.txt
#' @references \url https://web.archive.org/web/20051215000102/http://www.mirror.co.uk/news/allnews/page.cfm?objectid=14848162&method=full&siteid=50143
read.delim("us_election_2004.csv", stringsAsFactors=TRUE)
